Documentation
¶
Overview ¶
Package goap provides deterministic goal-oriented action planning over immutable planning.WorldState values. Its Planner uses uniform-cost search, which is complete and cost-optimal for the non-negative finite Action costs accepted by the Planning domain.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrExpansionLimitReached = errors.New("goap: expansion limit reached")
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// MaxExpansions bounds states removed from the frontier. Zero selects a safe
// default of 10,000 expansions.
MaxExpansions uint32
}
Config contains the bounded search policy for a GOAP Planner.
Click to show internal directories.
Click to hide internal directories.