Documentation
¶
Overview ¶
Package history instruments conversation-history capabilities with OpenTelemetry.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrInvalidConfig = errors.New("otel/history: invalid config")
Functions ¶
This section is empty.
Types ¶
type Middleware ¶
type Middleware struct {
// contains filtered or unexported fields
}
Middleware instruments history capabilities without entering a provider package or changing the wrapped operation's result.
func NewMiddleware ¶
func NewMiddleware(config MiddlewareConfig) (Middleware, error)
func (Middleware) Conversations ¶
func (m Middleware) Conversations(next corehistory.Lister) corehistory.Lister
Conversations instruments the optional cross-conversation listing capability without synthesizing it for stores that do not provide it.
func (Middleware) Store ¶
func (m Middleware) Store(next corehistory.Store) corehistory.Store
Store instruments the ordinary read, write, and clear capabilities.
type MiddlewareConfig ¶
type MiddlewareConfig struct {
System string
TracerProvider trace.TracerProvider
MeterProvider metric.MeterProvider
}
MiddlewareConfig identifies the storage system observed by history instrumentation.
func (MiddlewareConfig) Validate ¶
func (m MiddlewareConfig) Validate() error
Click to show internal directories.
Click to hide internal directories.